hash stringlengths 40 40 | diff stringlengths 131 114k | message stringlengths 7 980 | project stringlengths 5 67 | split stringclasses 1
value |
|---|---|---|---|---|
5dc7b6c9c59e25eb0a45b8d653e29553837516e2 | diff --git a/tests/TestCase/Model/Table/FooTableTest.php b/tests/TestCase/Model/Table/FooTableTest.php
index <HASH>..<HASH> 100644
--- a/tests/TestCase/Model/Table/FooTableTest.php
+++ b/tests/TestCase/Model/Table/FooTableTest.php
@@ -2,6 +2,7 @@
namespace CsvMigrations\Test\TestCase\Model\Table;
use Cake\Core\Conf... | Adjusted/extended unit tests for server side validation enabling | QoboLtd_cakephp-csv-migrations | train |
1bcd2b021e90adf91fe37d2cfaa14d7916bcdcdc | diff --git a/lib/SFTP/SFTPv3.js b/lib/SFTP/SFTPv3.js
index <HASH>..<HASH> 100644
--- a/lib/SFTP/SFTPv3.js
+++ b/lib/SFTP/SFTPv3.js
@@ -267,16 +267,16 @@ function fastXfer(src, dst, srcPath, dstPath, opts, cb) {
if (--left === 0)
cb(err);
};
+ if (srcfd)
+ ++left;
+ if (dstfd)... | SFTPv3: fix onerror for fast* methods | mscdex_ssh2 | train |
8feebbe600eb894597127d59f2ddd38f04af0648 | diff --git a/master/buildbot/test/unit/test_www_hooks_github.py b/master/buildbot/test/unit/test_www_hooks_github.py
index <HASH>..<HASH> 100644
--- a/master/buildbot/test/unit/test_www_hooks_github.py
+++ b/master/buildbot/test/unit/test_www_hooks_github.py
@@ -1,3 +1,4 @@
+# coding: utf-8
# This file is part of Buil... | Add test where in changes, author is unicode on Python 2. | buildbot_buildbot | train |
b44991ca3c88863a6aa67c3a7cefe2537c18be99 | diff --git a/initrd/driver/virtio.js b/initrd/driver/virtio.js
index <HASH>..<HASH> 100644
--- a/initrd/driver/virtio.js
+++ b/initrd/driver/virtio.js
@@ -73,27 +73,27 @@ var VRing = (function() {
self.view.setUint16(base + DescriptorTable.OFFSET_NEXT, next >>> 0, true);
};
- DescriptorTable.prototyp... | Optimize virtio driver a bit | runtimejs_runtime | train |
cc9291a90ce4406da80d3c71722db199c48df815 | diff --git a/Form/Type/TranslatableChoiceType.php b/Form/Type/TranslatableChoiceType.php
index <HASH>..<HASH> 100644
--- a/Form/Type/TranslatableChoiceType.php
+++ b/Form/Type/TranslatableChoiceType.php
@@ -62,6 +62,7 @@ class TranslatableChoiceType extends AbstractType
if (!empty($view->vars['empty_value'])) ... | Expanded choices are now translated
Expanded choices are added to the form by the $options[choice_list] which was never translated. The translation_domain option of the view was never set, so is always getting the default (messages) value.
I update the translation_domain with the $options['catalogue'] to resolve this... | sonata-project_SonataAdminBundle | train |
c1c2236bbd8340c99e7755cc6bd22279978abb93 | diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -306,7 +306,7 @@ function processPaths(container,containerName,options,requestBodyCache,openapi)
}
if (response.$ref.indexOf('#/definitions/')>=0) {
//response.$ref = '#/components/schemas/'+common.sa... | Add some minimal context to thrown errors | wework_speccy | train |
a12ff950aa91d72e3cfe187d4b905b44acbc3eb7 | diff --git a/src/Roles.php b/src/Roles.php
index <HASH>..<HASH> 100644
--- a/src/Roles.php
+++ b/src/Roles.php
@@ -7,7 +7,7 @@ class Roles
/**
* Get all user roles from WordPress
*
- * @param boolean $include_admin
+ * @param bool $include_admin
* @return array
*/
public static... | Update boolean to bool | soberwp_intervention | train |
0c476ddd05dddb15262be515c7624e4e7cbc8a4b | diff --git a/eZ/Publish/Core/Persistence/Legacy/Content/FieldValue/Converter/Float.php b/eZ/Publish/Core/Persistence/Legacy/Content/FieldValue/Converter/Float.php
index <HASH>..<HASH> 100644
--- a/eZ/Publish/Core/Persistence/Legacy/Content/FieldValue/Converter/Float.php
+++ b/eZ/Publish/Core/Persistence/Legacy/Content/... | Changed: adapted Float field type according to the refactoring | ezsystems_ezpublish-kernel | train |
b3bcee2457578497396a0af275bfe962f3dedb46 | diff --git a/course/index.php b/course/index.php
index <HASH>..<HASH> 100644
--- a/course/index.php
+++ b/course/index.php
@@ -258,7 +258,7 @@
}
/// Find any orphan courses that don't yet have a valid category and set to default
- if ($courses = get_courses(NULL,NULL,'c.category,c.id,c.sortorder')) {
+ if... | First field must be unique in every select. Bug <I>.
(<URL>)
Merged from MOODLE_<I>_STABLE | moodle_moodle | train |
ffb403d9b5a29ca40eda40661acf8f176b7f3a8b | diff --git a/repository/filepicker.js b/repository/filepicker.js
index <HASH>..<HASH> 100644
--- a/repository/filepicker.js
+++ b/repository/filepicker.js
@@ -290,6 +290,12 @@ YUI.add('moodle-core_filepicker', function(Y) {
Y.bind(callback, options.callbackcontext)(e, e.node.fileinfo);
... | MDL-<I> filepicker: view file not available using keyboard (Enter) | moodle_moodle | train |
b892553edcead015b25f6bf7618f66f64c62064e | diff --git a/src/sos/step_executor.py b/src/sos/step_executor.py
index <HASH>..<HASH> 100755
--- a/src/sos/step_executor.py
+++ b/src/sos/step_executor.py
@@ -801,7 +801,6 @@ class Base_Step_Executor:
env.sos_dict.set('step_input', sos_targets([]))
else:
env.sos_dict.set('step_input',... | Recording for_each variables in _input and _output #<I> | vatlab_SoS | train |
903842fcaf8cb42554e5ced804a919a59c33a39a | diff --git a/threadedcomments/templatetags/threadedcomments_tags.py b/threadedcomments/templatetags/threadedcomments_tags.py
index <HASH>..<HASH> 100644
--- a/threadedcomments/templatetags/threadedcomments_tags.py
+++ b/threadedcomments/templatetags/threadedcomments_tags.py
@@ -7,19 +7,11 @@ from threadedcomments.util ... | Move flat/root_only logic to BaseThreadedCommentNode
Allow to be used by any `get_whatever` node | HonzaKral_django-threadedcomments | train |
ff8cb2fd1931ee83124028a06ecb1b3d61b2b576 | diff --git a/lib/import_js/importer.rb b/lib/import_js/importer.rb
index <HASH>..<HASH> 100644
--- a/lib/import_js/importer.rb
+++ b/lib/import_js/importer.rb
@@ -4,11 +4,6 @@ require 'strscan'
module ImportJS
class Importer
- REGEX_USE_STRICT = /(['"])use strict\1;?\n/
- REGEX_SINGLE_LINE_COMMENT = %r{\s*/... | Move Importer regexes closer to where they are used
I think that this will help the code here be more readable. | Galooshi_import-js | train |
f5a5c37905dd070231ab0ecc7511a3ee58a18b45 | diff --git a/examples/events/index.js b/examples/events/index.js
index <HASH>..<HASH> 100644
--- a/examples/events/index.js
+++ b/examples/events/index.js
@@ -55,6 +55,8 @@ primus.on('connection', function connection(spark) {
console.log('new connection');
spark.on('data', function data(packet) {
+ if (!pack... | [fix] Don't allow receiving of undefineds | primus_primus | train |
ecbaed2cf48ff3885ba0820c81f6ef96ce00d29b | diff --git a/clevertap-core/src/main/java/com/clevertap/android/sdk/Utils.java b/clevertap-core/src/main/java/com/clevertap/android/sdk/Utils.java
index <HASH>..<HASH> 100644
--- a/clevertap-core/src/main/java/com/clevertap/android/sdk/Utils.java
+++ b/clevertap-core/src/main/java/com/clevertap/android/sdk/Utils.java
@... | task(SDK-<I>) - Add check for whether FirebaseInstanceId is available for version of FirebaseMessaging greater than <I> | CleverTap_clevertap-android-sdk | train |
7699eae652abf91d9303a5bd364ff0e36481f6b4 | diff --git a/core/src/main/java/org/primefaces/extensions/application/PrimeFacesScriptProcessor.java b/core/src/main/java/org/primefaces/extensions/application/PrimeFacesScriptProcessor.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/org/primefaces/extensions/application/PrimeFacesScriptProcessor.java
+++ b/c... | Fix #<I>: Removed ID causing script to be a SPAN | primefaces-extensions_core | train |
940931a9cb8d6ced46f199c41cd2c58841264f07 | diff --git a/TODO.txt b/TODO.txt
index <HASH>..<HASH> 100644
--- a/TODO.txt
+++ b/TODO.txt
@@ -1,6 +1,3 @@
-* Make sure request headers are all handled in a case-insensitive manner.
-* Send correct response codes for unknown vs. unimplemented method (405 vs. 501)
-* Implement HEAD method, defaulting to GET
* Think abo... | Response with <I> code for unknown methods. | pneff_wsgiservice | train |
e295ba3da8e48f7defe35bc75aa335dfb2e581f8 | diff --git a/src/Netcraft.php b/src/Netcraft.php
index <HASH>..<HASH> 100644
--- a/src/Netcraft.php
+++ b/src/Netcraft.php
@@ -128,6 +128,13 @@ class Netcraft extends Parser
$events[] = $event;
}
+ if (empty($events)) {
+ return $this->failed(
+ config("{$configB... | make sure something has been done, else fail | AbuseIO_parser-netcraft | train |
d6f2611a2b6c4b308d4acfbdbd563fdc31f87bc6 | diff --git a/openquake/engine/db/models.py b/openquake/engine/db/models.py
index <HASH>..<HASH> 100644
--- a/openquake/engine/db/models.py
+++ b/openquake/engine/db/models.py
@@ -76,10 +76,6 @@ IMT_CHOICES = (
(u'MMI', u'Modified Mercalli Intensity'),
)
-#: Default Loss Curve Resolution used for probabilistic r... | Remove the loss_curve_resolution default, since it is done in commonlib.readinput
Former-commit-id: 2dbbd4ec9c3f5d<I>ebc4f<I>a<I>ce2c<I>fb<I>af | gem_oq-engine | train |
1cde036b99f4ded5f89e8a69d2fdae9bf88b833a | diff --git a/Tests/js/views/fields/assets/ez-url-editview-tests.js b/Tests/js/views/fields/assets/ez-url-editview-tests.js
index <HASH>..<HASH> 100644
--- a/Tests/js/views/fields/assets/ez-url-editview-tests.js
+++ b/Tests/js/views/fields/assets/ez-url-editview-tests.js
@@ -1,25 +1,5 @@
YUI.add('ez-url-editview-tests'... | Refactored the url edit view test to not use any "global" variable | ezsystems_PlatformUIBundle | train |
45d644aab2e49d5d4bbdc397757101e05aeb2273 | diff --git a/lib/fog/rackspace/files.rb b/lib/fog/rackspace/files.rb
index <HASH>..<HASH> 100644
--- a/lib/fog/rackspace/files.rb
+++ b/lib/fog/rackspace/files.rb
@@ -21,12 +21,13 @@ module Fog
@cdn_path = cdn_uri.path
@cdn_port = cdn_uri.port
@cdn_scheme = cdn_uri.scheme
+ @cdn_co... | distinguish between storage/cdn requests for rackspace files | fog_fog | train |
3f4fbf60ef249bad5e88d70f9d441f9a5d206dfb | diff --git a/lxd/migrate_instance.go b/lxd/migrate_instance.go
index <HASH>..<HASH> 100644
--- a/lxd/migrate_instance.go
+++ b/lxd/migrate_instance.go
@@ -922,6 +922,15 @@ func (c *migrationSink) Do(state *state.State, revert *revert.Reverter, migrateO
// The migration header to be sent back to source with our target... | lxd/migrate/instance: Update migrationSink.Do to support migration index header | lxc_lxd | train |
bad2fecdaea3606fd05d31f353e7b68e2f0926d2 | diff --git a/Metamusic/__init__.py b/Metamusic/__init__.py
index <HASH>..<HASH> 100644
--- a/Metamusic/__init__.py
+++ b/Metamusic/__init__.py
@@ -99,6 +99,7 @@ class MetaMusic():
sid = database.insert_song(file_hash=hashes_sha1[num],
song_name=song_name)
... | largebinary changed to binary and some other minor changes | unique1o1_Meta-Music | train |
4433ec6837acc2c9f20a8cf4f18e48f5b1f6391d | diff --git a/opaque_keys/__init__.py b/opaque_keys/__init__.py
index <HASH>..<HASH> 100644
--- a/opaque_keys/__init__.py
+++ b/opaque_keys/__init__.py
@@ -373,8 +373,8 @@ class OpaqueKey(object):
return not self == other
def __lt__(self, other):
- if type(self) != type(other):
- raise ... | Allow comparison of OpaqueKeys that have the same set of fields (and the same deprecation status) | edx_opaque-keys | train |
e7a547970d2d5348967d642045bc01e3006cae67 | diff --git a/deisctl/cmd/cmd.go b/deisctl/cmd/cmd.go
index <HASH>..<HASH> 100644
--- a/deisctl/cmd/cmd.go
+++ b/deisctl/cmd/cmd.go
@@ -83,6 +83,7 @@ Usage:
wg.Wait()
}
close(outchan)
+ close(errchan)
return nil
}
@@ -119,6 +120,7 @@ Usage:
b.Start(targets, &wg, outchan, errchan)
wg.Wait()
close(outcha... | fix(deisctl): avoid blocking if output is empty | deis_deis | train |
1059dede4c4a1c042e3f4fe9f7fbfcc78146b233 | diff --git a/activerecord/test/cases/associations/has_many_through_associations_test.rb b/activerecord/test/cases/associations/has_many_through_associations_test.rb
index <HASH>..<HASH> 100644
--- a/activerecord/test/cases/associations/has_many_through_associations_test.rb
+++ b/activerecord/test/cases/associations/has... | Fix test that was broken by adding a default scope to an existing model | rails_rails | train |
998c10d84c41e0d4b2868b9f2307495394b0d670 | diff --git a/lib/cisco_node_utils/cmd_ref/inventory.yaml b/lib/cisco_node_utils/cmd_ref/inventory.yaml
index <HASH>..<HASH> 100644
--- a/lib/cisco_node_utils/cmd_ref/inventory.yaml
+++ b/lib/cisco_node_utils/cmd_ref/inventory.yaml
@@ -21,16 +21,16 @@ productid:
ios_xr:
get_value: '/"Rack 0".*\n.*PID: ([^ ,]+)/'... | Fix similar vlan id issue (#<I>)
* Inital commit
* Update vlan.yaml
* Add similar id test and escape special characters | cisco_cisco-network-node-utils | train |
5506b96baa8686427d27caec87bd6f6d3b546b58 | diff --git a/test/jetstream_test.go b/test/jetstream_test.go
index <HASH>..<HASH> 100644
--- a/test/jetstream_test.go
+++ b/test/jetstream_test.go
@@ -3954,6 +3954,96 @@ func TestJetStreamDurableConsumerReconnect(t *testing.T) {
}
}
+func TestJetStreamDurableConsumerReconnectWithOnlyPending(t *testing.T) {
+ cases... | AddConsumer causes redelivery of first message
It seems that when updating the delivery subject, we use as the
first sequence the ack floor, but if no message was ever ack'ed
then it causes the first message to be redelivered twice.
Resolves #<I> | nats-io_gnatsd | train |
e0420937a7883914ea79ee0519c90938109ecfe2 | diff --git a/cake/libs/controller/components/security.php b/cake/libs/controller/components/security.php
index <HASH>..<HASH> 100644
--- a/cake/libs/controller/components/security.php
+++ b/cake/libs/controller/components/security.php
@@ -689,7 +689,7 @@ class SecurityComponent extends Component {
$tokenData = array... | Fixing notice error that could occur if csrfTokens ended up being null/not an array. | cakephp_cakephp | train |
875acdc8a1b650480c663ef9cb4fb7ac4af9c7dc | diff --git a/lib/emir/recipes/auxiliary.py b/lib/emir/recipes/auxiliary.py
index <HASH>..<HASH> 100644
--- a/lib/emir/recipes/auxiliary.py
+++ b/lib/emir/recipes/auxiliary.py
@@ -618,7 +618,7 @@ class SlitTransmissionRecipe(BaseRecipe):
version="0.1.0"
)
- @log_to_history(_logger)
+ @log_t... | Update log_to_history to use two arguments | guaix-ucm_pyemir | train |
2f681820c5bd0a2e7b4e981963bc769f8e147282 | diff --git a/aiohttp/web_urldispatcher.py b/aiohttp/web_urldispatcher.py
index <HASH>..<HASH> 100644
--- a/aiohttp/web_urldispatcher.py
+++ b/aiohttp/web_urldispatcher.py
@@ -442,7 +442,7 @@ class StaticRoute(Route):
try:
directory = Path(directory)
if str(directory).startswith('~'):
... | Python <I> has no Path.expanduser | aio-libs_aiohttp | train |
897c203e6217378dbc8bcd08771727c74e151f96 | diff --git a/go.sum b/go.sum
index <HASH>..<HASH> 100644
--- a/go.sum
+++ b/go.sum
@@ -369,6 +369,7 @@ golang.org/x/crypto v0.0.0-20191011191535-87dc89f01550 h1:ObdrDkeb4kJdCP557AjRjq
golang.org/x/crypto v0.0.0-20191011191535-87dc89f01550/go.mod h1:yigFU9vqHzYiE8UmvKecakEJjdnWj3jj499lnFckfCI=
golang.org/x/crypto v0.0... | Reset the state of TLS rule after each version check (#<I>) | securego_gosec | train |
809493e7175522fcf5f1048179f150f6f59694c3 | diff --git a/lib/rack/reverse_proxy.rb b/lib/rack/reverse_proxy.rb
index <HASH>..<HASH> 100644
--- a/lib/rack/reverse_proxy.rb
+++ b/lib/rack/reverse_proxy.rb
@@ -63,7 +63,11 @@ module Rack
target_response.verify_ssl = options[:verify_ssl]
target_response.timeout = options[:timeout]
- [target_respo... | Deleting transfer-encoding header from response so rack can set it | waterlink_rack-reverse-proxy | train |
8999deb1fcfca4b7f6f31c6f1673c3dacf4c6ed0 | diff --git a/lib/ra10ke/validate.rb b/lib/ra10ke/validate.rb
index <HASH>..<HASH> 100644
--- a/lib/ra10ke/validate.rb
+++ b/lib/ra10ke/validate.rb
@@ -44,12 +44,12 @@ module Ra10ke
# @return [Array[Hash]] array of module information and git status
def all_modules
@all_modules ||= begin
+ ... | Cache the current r<I>k branch
There's no reason to check the branch again for every module | voxpupuli_ra10ke | train |
af81f443372d4c921b4da832025acda4edde8862 | diff --git a/filesystem/File.php b/filesystem/File.php
index <HASH>..<HASH> 100755
--- a/filesystem/File.php
+++ b/filesystem/File.php
@@ -259,7 +259,7 @@ class File extends DataObject {
* @return String
*/
public function appCategory() {
- $ext = $this->Extension;
+ $ext = strtolower($this->Extension);
sw... | [BUGFIX] Files with uppercase extensions were not being assigned an appCategory() | silverstripe_silverstripe-framework | train |
294f272656570dae37a98de92f6738c08f0e73e4 | diff --git a/src/Properties/ReflectionTypeContainer.php b/src/Properties/ReflectionTypeContainer.php
index <HASH>..<HASH> 100644
--- a/src/Properties/ReflectionTypeContainer.php
+++ b/src/Properties/ReflectionTypeContainer.php
@@ -13,12 +13,12 @@ declare(strict_types=1);
namespace NunoMaduro\Larastan\Properties;
-... | Fixed compatibility with PHPStan <I> | nunomaduro_larastan | train |
ec6a3408e00328844dbcb4a3d848003a1e61a8d4 | diff --git a/jaraco/packaging/depends.py b/jaraco/packaging/depends.py
index <HASH>..<HASH> 100644
--- a/jaraco/packaging/depends.py
+++ b/jaraco/packaging/depends.py
@@ -58,7 +58,12 @@ def check_dependencies(req, indent=1, history=None):
def load_dependencies(req, history=None):
"""
- Load the dependency tr... | Extend documentation including a new doctest | jaraco_jaraco.packaging | train |
4b49b0b045f48771fcaa8e1fb62b7f520dd0c29d | diff --git a/django_mailbox/__init__.py b/django_mailbox/__init__.py
index <HASH>..<HASH> 100644
--- a/django_mailbox/__init__.py
+++ b/django_mailbox/__init__.py
@@ -1 +1 @@
-__version__ = '4.4.3'
+__version__ = '4.4.4' | Release <I>; prevents exceptions occurring in signal handlers from being swallowed. | coddingtonbear_django-mailbox | train |
0be9927256e7008b8365083667860c7ddc2029c8 | diff --git a/code/libraries/koowa/libraries/view/html.php b/code/libraries/koowa/libraries/view/html.php
index <HASH>..<HASH> 100644
--- a/code/libraries/koowa/libraries/view/html.php
+++ b/code/libraries/koowa/libraries/view/html.php
@@ -67,22 +67,15 @@ class KViewHtml extends KViewTemplate
}
/**
- * Get ... | re #<I> : Force a route to be not fully qualified and escaped by default | timble_kodekit | train |
42d28719d26f477fa20eb7f5b185998046def303 | diff --git a/src/interactivity/Interactivity.js b/src/interactivity/Interactivity.js
index <HASH>..<HASH> 100644
--- a/src/interactivity/Interactivity.js
+++ b/src/interactivity/Interactivity.js
@@ -114,6 +114,7 @@ export default class Interactivity {
enable () {
this._enabled = true;
}
+
_init ... | Add tests for enable / disable interactivity (manual and automatic) | CartoDB_carto-vl | train |
5e36fb482c99b492750a02bf2ca978381f93e0d5 | diff --git a/pytestsalt/fixtures/daemons.py b/pytestsalt/fixtures/daemons.py
index <HASH>..<HASH> 100644
--- a/pytestsalt/fixtures/daemons.py
+++ b/pytestsalt/fixtures/daemons.py
@@ -629,6 +629,102 @@ def salt_minion(salt_master,
log.info('[%s] pytest salt-minion(%s) stopped', minion_log_prefix, minion_id)
+@p... | Add session scoped salt-minion fixtures | saltstack_pytest-salt | train |
5f1ac9e0a0b8feed2a817103c0c302f976489bb8 | diff --git a/core/src/main/java/org/infinispan/notifications/AbstractListenerImpl.java b/core/src/main/java/org/infinispan/notifications/AbstractListenerImpl.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/org/infinispan/notifications/AbstractListenerImpl.java
+++ b/core/src/main/java/org/infinispan/notificat... | findbugs: Inefficient use of keySet iterator instead of entrySet iterator
This method accesses the value of a Map entry, using a key that was retrieved from a keySet iterator. It is more efficient to use an iterator on the entrySet of the map, to avoid the Map.get(key) lookup. | infinispan_infinispan | train |
3738109b9339fef9a05c421a30c9ce4d8f4c67f1 | diff --git a/demos/client_ids.js b/demos/client_ids.js
index <HASH>..<HASH> 100644
--- a/demos/client_ids.js
+++ b/demos/client_ids.js
@@ -94,7 +94,8 @@ var CLIENT_IDS_ALL = {
soundcloud : SOUNDCLOUD_CLIENT_ID,
foursquare : FOURSQUARE_CLIENT_ID,
github : GITHUB_CLIENT_ID,
- flickr: FLICKR_CLIENT_ID
+ flickr: FLIC... | Added vk.js | MrSwitch_hello.js | train |
7cf9b8b806198e0d05cf11cb21386b792aa6ad8d | diff --git a/bika/lims/browser/worksheet/worksheets.py b/bika/lims/browser/worksheet/worksheets.py
index <HASH>..<HASH> 100644
--- a/bika/lims/browser/worksheet/worksheets.py
+++ b/bika/lims/browser/worksheet/worksheets.py
@@ -27,7 +27,7 @@ class WorksheetsView(BikaListingView):
implements(IFolderContentsView, I... | worksheetfolder.pt to worksheets.pt | senaite_senaite.core | train |
579ffa5c96e1d292c060b3dd62811ff01ad8c24e | diff --git a/src/Mustache/Compiler.php b/src/Mustache/Compiler.php
index <HASH>..<HASH> 100644
--- a/src/Mustache/Compiler.php
+++ b/src/Mustache/Compiler.php
@@ -320,7 +320,6 @@ class Mustache_Compiler
}
const SECTION_CALL = '
- // %s section
$value = $context->%s(%s);%s
$buffer .=... | Fix CVE-<I>-<I> (improper neutralization of section names)
- Fixes possible RCE when rendering untrusted user templates.
- Remove unnecessary comments in generated source. | bobthecow_mustache.php | train |
c02dcea7d14fbd48db613d74674e1573e606878a | diff --git a/src/tuwien/auto/calimero/link/medium/KNXMediumSettings.java b/src/tuwien/auto/calimero/link/medium/KNXMediumSettings.java
index <HASH>..<HASH> 100644
--- a/src/tuwien/auto/calimero/link/medium/KNXMediumSettings.java
+++ b/src/tuwien/auto/calimero/link/medium/KNXMediumSettings.java
@@ -52,8 +52,10 @@ public... | Mark medium codes phased out by the specification | calimero-project_calimero-core | train |
b1ba8bd05b5b61e9f9ec4e1316facba570b841db | diff --git a/control/HTTP.php b/control/HTTP.php
index <HASH>..<HASH> 100644
--- a/control/HTTP.php
+++ b/control/HTTP.php
@@ -62,9 +62,8 @@ class HTTP {
public static function absoluteURLs($html) {
$html = str_replace('$CurrentPageURL', $_SERVER['REQUEST_URI'], $html);
return HTTP::urlRewriter($html, function(... | FIX: Updated protocol check to become more stringent. | silverstripe_silverstripe-framework | train |
c23cbfebdc02370f2c0d5eeb62ef316e4cfeddc8 | diff --git a/Resolver/AccessResolver.php b/Resolver/AccessResolver.php
index <HASH>..<HASH> 100644
--- a/Resolver/AccessResolver.php
+++ b/Resolver/AccessResolver.php
@@ -14,6 +14,8 @@ namespace Overblog\GraphQLBundle\Resolver;
use GraphQL\Executor\Promise\Adapter\SyncPromise;
use GraphQL\Executor\Promise\Promise;
u... | Fix data leaked to unauthorized users
fixed #<I> | overblog_GraphQLBundle | train |
a481603480ba0db44c85ab1ef64f3c0a34c16457 | diff --git a/activerecord/test/cases/relation/delegation_test.rb b/activerecord/test/cases/relation/delegation_test.rb
index <HASH>..<HASH> 100644
--- a/activerecord/test/cases/relation/delegation_test.rb
+++ b/activerecord/test/cases/relation/delegation_test.rb
@@ -54,4 +54,32 @@ module ActiveRecord
Comment.all... | Add `QueryingMethodsDelegationTest` to cover query methods delegation
It makes to ease to detect a future regression as long as the methods
are covered by this test. | rails_rails | train |
527cb2799108bf64481a65286382c14927ce41bd | diff --git a/lib/easy_app_helper/core/base.rb b/lib/easy_app_helper/core/base.rb
index <HASH>..<HASH> 100644
--- a/lib/easy_app_helper/core/base.rb
+++ b/lib/easy_app_helper/core/base.rb
@@ -106,6 +106,17 @@ class EasyAppHelper::Core::Base
internal_configs.keys
end
+ def safely_exec(message, *args)
+ rais... | Added safely_exec method in conjunction with --simulate. | lbriais_easy_app_helper | train |
b20780e9888133e7660d01b0ca06a41d8a4d0840 | diff --git a/packages/build-tools/utils/manifest.js b/packages/build-tools/utils/manifest.js
index <HASH>..<HASH> 100644
--- a/packages/build-tools/utils/manifest.js
+++ b/packages/build-tools/utils/manifest.js
@@ -236,13 +236,17 @@ async function writeTwigNamespaceFile(relativeFrom, extraNamespaces = {}) {
if (extr... | fix: update build tools logic to ensure setting a namespace key but NOT a paths config doesn't blow up the build on the Node or PHP side of things. | bolt-design-system_bolt | train |
c4183917ceffd162bf9564c0efa5f5babe223f84 | diff --git a/lib/authority/controller.rb b/lib/authority/controller.rb
index <HASH>..<HASH> 100644
--- a/lib/authority/controller.rb
+++ b/lib/authority/controller.rb
@@ -24,7 +24,7 @@ module Authority
def authority_forbidden(error)
Authority.configuration.logger.warn(error.message)
- render :file =>... | Don't render a layout for forbidden | nathanl_authority | train |
9fec4e331b93b2f7774803fd36af6cef4451861d | diff --git a/lib/adminlib.php b/lib/adminlib.php
index <HASH>..<HASH> 100644
--- a/lib/adminlib.php
+++ b/lib/adminlib.php
@@ -1662,7 +1662,7 @@ class admin_setting_courselist_frontpage extends admin_setting_configselect {
FRONTPAGECATEGORYNAMES => get_string('frontpagecategorynames'),
... | MDL-<I> Course list option missing in frontpageloggedin when there are more than <I> courses | moodle_moodle | train |
1e242cbee4bfc6729c2ebd55d2dad6fdb3768bca | diff --git a/losantrest/client.py b/losantrest/client.py
index <HASH>..<HASH> 100644
--- a/losantrest/client.py
+++ b/losantrest/client.py
@@ -26,7 +26,6 @@ SOFTWARE.
# pylint: disable=E0401
import requests
-import collections
import sys
from .application import Application
from .application_api_token import App... | Import ABC from collections.abc for Python <I> compatibility. | Losant_losant-rest-python | train |
4cf02b2e5a45661e28f9dd358f1f25426a25901c | diff --git a/retrofit-mock/src/main/java/retrofit/MockRestAdapter.java b/retrofit-mock/src/main/java/retrofit/MockRestAdapter.java
index <HASH>..<HASH> 100644
--- a/retrofit-mock/src/main/java/retrofit/MockRestAdapter.java
+++ b/retrofit-mock/src/main/java/retrofit/MockRestAdapter.java
@@ -8,12 +8,13 @@ import java.lan... | Simplify scheduling of mock observers. | square_retrofit | train |
3a931d61b3be37d222a9b076c9f3db6e4c828fdc | diff --git a/test/feature.test.js b/test/feature.test.js
index <HASH>..<HASH> 100644
--- a/test/feature.test.js
+++ b/test/feature.test.js
@@ -4,6 +4,7 @@ var mapnik = require('../');
var assert = require('assert');
var path = require('path');
+mapnik.register_datasource(path.join(mapnik.settings.paths.input_plugin... | Add test for stringifying objects in JSON - refs #<I> and mapnik/mapnik#<I> | mapnik_node-mapnik | train |
1fa2192d0ff8abf74842bd861f566d6646916193 | diff --git a/astbuilder.go b/astbuilder.go
index <HASH>..<HASH> 100644
--- a/astbuilder.go
+++ b/astbuilder.go
@@ -1,7 +1,7 @@
package gherkin
import (
- "github.com/cucumber/messages-go/v10"
+ "github.com/cucumber/messages-go/v11"
"strings"
)
diff --git a/bench_test.go b/bench_test.go
index <HASH>..<HASH> 100... | Go: Point to github.com/cucumber/messages-go/<I> <I> | cucumber_gherkin-go | train |
05dfc6bb20ff75b79b5231d8547b60f615215514 | diff --git a/src/canvas/view/CanvasView.js b/src/canvas/view/CanvasView.js
index <HASH>..<HASH> 100644
--- a/src/canvas/view/CanvasView.js
+++ b/src/canvas/view/CanvasView.js
@@ -253,6 +253,12 @@ module.exports = Backbone.View.extend({
this.frame.el.contentWindow.onscroll = this.onFrameScroll;
this.frame.... | Avoid the default link behaviour in the canvas | artf_grapesjs | train |
4e76f433ff07e51b274cb73590c8c48515afeb27 | diff --git a/lib/plugins/cli.js b/lib/plugins/cli.js
index <HASH>..<HASH> 100644
--- a/lib/plugins/cli.js
+++ b/lib/plugins/cli.js
@@ -61,6 +61,25 @@ exports = module.exports = function(){
return function(master){
requirePIDs(master);
+ // augment master
+ master.killall = function(sig){
+ var pid ... | Added; cli commands will now signal orphaned children | LearnBoost_cluster | train |
174e02a2b71fd51ff27f9186526352d79253da26 | diff --git a/lib/puppet.rb b/lib/puppet.rb
index <HASH>..<HASH> 100644
--- a/lib/puppet.rb
+++ b/lib/puppet.rb
@@ -93,7 +93,7 @@ module Puppet
def self.run_mode
require 'puppet/util/run_mode'
- $puppet_application_mode || Puppet::Util::RunMode.new( :user )
+ $puppet_application_mode || Pup... | [#<I>] Change how RunMode instances are created so that an object for each RunMode is only created once instead of every time it's called
Got lots of unpredictable test failures, presumably because a new
RunMode was being created every time we accessed the RunMode. | puppetlabs_puppet | train |
ae5c7cb81d6a074e3df2bb6843226502e745e51b | diff --git a/java/src/org/openqa/selenium/grid/router/HandleSession.java b/java/src/org/openqa/selenium/grid/router/HandleSession.java
index <HASH>..<HASH> 100644
--- a/java/src/org/openqa/selenium/grid/router/HandleSession.java
+++ b/java/src/org/openqa/selenium/grid/router/HandleSession.java
@@ -20,6 +20,7 @@ package... | [grid] Add error message and exception type if the session does not exist | SeleniumHQ_selenium | train |
007bf47f1070be56fdaa50daa1fefd6c0d219ca5 | diff --git a/lib/moodlelib.php b/lib/moodlelib.php
index <HASH>..<HASH> 100644
--- a/lib/moodlelib.php
+++ b/lib/moodlelib.php
@@ -8394,7 +8394,14 @@ function check_php_version($version='5.2.4') {
if (empty($version)) {
return true; // no version specified
}
- if (preg_matc... | MDL-<I> Fix bugs in previous commit | moodle_moodle | train |
a3ff7cadb0f266027de4ea89d9f99f8d31f88661 | diff --git a/lib/visitor/compiler.js b/lib/visitor/compiler.js
index <HASH>..<HASH> 100644
--- a/lib/visitor/compiler.js
+++ b/lib/visitor/compiler.js
@@ -174,8 +174,8 @@ Compiler.prototype.visitBlock = function(block){
*/
Compiler.prototype.visitKeyframes = function(node){
- // IE never had prefixes for keyframe... | Fixed bug with undefined `filename` on keyframes. Closes #<I> | stylus_stylus | train |
6ba2ebbab3cdc9d7febaa77ad6d30c70498a7336 | diff --git a/lib/chore/strategies/worker/single_worker_strategy.rb b/lib/chore/strategies/worker/single_worker_strategy.rb
index <HASH>..<HASH> 100644
--- a/lib/chore/strategies/worker/single_worker_strategy.rb
+++ b/lib/chore/strategies/worker/single_worker_strategy.rb
@@ -21,13 +21,20 @@ module Chore
worker.... | If the single worker raises an exception, ensure that it is released
also log re-entry of #assign | Tapjoy_chore | train |
bced924f72ed6a5a62d0f7b13bf932c2dc9e1a44 | diff --git a/azure-client-runtime/src/main/java/com/microsoft/azure/AzureClient.java b/azure-client-runtime/src/main/java/com/microsoft/azure/AzureClient.java
index <HASH>..<HASH> 100644
--- a/azure-client-runtime/src/main/java/com/microsoft/azure/AzureClient.java
+++ b/azure-client-runtime/src/main/java/com/microsoft/... | Run polling in immediate scheduler (#<I>)
* Run polling in immediate scheduler
* Remove unnecessary immediate scheduler | Azure_autorest-clientruntime-for-java | train |
9509389f871a20465740494dd32a8d581572dd63 | diff --git a/grammpy/Rule.py b/grammpy/Rule.py
index <HASH>..<HASH> 100644
--- a/alot/addressbooks.py
+++ b/alot/addressbooks.py
@@ -9,6 +9,10 @@ from helper import call_cmd
from alot.helper import split_commandstring
+class AddressbookError(Exception):
+ pass
+
+
class AddressBook(object):
"""c... | handle errors of external cmds in MatchSdtoutAddressbook
issue #<I> | pazz_alot | train |
39426bb1cb0efb1b2b254567f91e9ff12049c192 | diff --git a/facepy/graph_api.py b/facepy/graph_api.py
index <HASH>..<HASH> 100644
--- a/facepy/graph_api.py
+++ b/facepy/graph_api.py
@@ -255,6 +255,8 @@ class GraphAPI(object):
response = self.session.request(method, url, data=data, files=files,
verify=self.verify_ssl_c... | Handle Facebook <I> with exception. | jgorset_facepy | train |
de9a80dbfb80473c39959e463e942292162dcb79 | diff --git a/lib/commander/help_generators/default.rb b/lib/commander/help_generators/default.rb
index <HASH>..<HASH> 100644
--- a/lib/commander/help_generators/default.rb
+++ b/lib/commander/help_generators/default.rb
@@ -58,8 +58,9 @@ module Commander
end
def render_description
+ return i... | - Added syntax to help generator | commander-rb_commander | train |
22751b07243a3bd749917e4e65dd239ebb5e9dd3 | diff --git a/doc/src/main/asciidoc/inc/generator/_options_common.adoc b/doc/src/main/asciidoc/inc/generator/_options_common.adoc
index <HASH>..<HASH> 100644
--- a/doc/src/main/asciidoc/inc/generator/_options_common.adoc
+++ b/doc/src/main/asciidoc/inc/generator/_options_common.adoc
@@ -25,6 +25,10 @@ There are some con... | Fix #<I> by adding a registry option | fabric8io_fabric8-maven-plugin | train |
cc2faf5117c7a0e2d5e469990c26bdad4f1c3931 | diff --git a/framework/validators/CFileValidator.php b/framework/validators/CFileValidator.php
index <HASH>..<HASH> 100644
--- a/framework/validators/CFileValidator.php
+++ b/framework/validators/CFileValidator.php
@@ -246,11 +246,11 @@ class CFileValidator extends CValidator
public function sizeToBytes($sizeStr)
{... | Removed extra case's in the CFileValidator::sizeToBytes() method. | yiisoft_yii | train |
f8983166d897a28ad72a9812271801fc197c327f | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -22,7 +22,7 @@ setup(
classifiers = [],
install_requires = [
'ansimarkup>=1.3.0',
- 'better_exceptions_fork>=0.1.8.post1',
+ 'better_exceptions_fork>=0.1.8.post2',
'pendulum>=1.3.0',
... | Bump required "better_exceptions_fork" version to <I>.post2 | Delgan_loguru | train |
54e2f1df9ee6e0a35cde75e1ee9ec5df778b09fc | diff --git a/bin/analyze-css.js b/bin/analyze-css.js
index <HASH>..<HASH> 100755
--- a/bin/analyze-css.js
+++ b/bin/analyze-css.js
@@ -19,6 +19,8 @@ program
.describe('url', 'Set URL of CSS to analyze').string('url')
.describe('file', 'Set local CSS file to analyze').string('file')
+ .describe('pretty', 'Causes J... | Add pretty print option
Resolves #6 | macbre_analyze-css | train |
cb962021c53b7130bf0a1792f75678efcc0724be | diff --git a/setuptools/tests/test_develop.py b/setuptools/tests/test_develop.py
index <HASH>..<HASH> 100644
--- a/setuptools/tests/test_develop.py
+++ b/setuptools/tests/test_develop.py
@@ -8,6 +8,7 @@ import io
import subprocess
import platform
import pathlib
+import textwrap
from setuptools.command import test... | Illustrate how one might leverage sitecustomize.py to make a project available on PYTHONPATH. Fixes #<I>. | pypa_setuptools | train |
e14c25fc9aff082ac779dae3a72fc54ccc0bb20a | diff --git a/SoftLayer/tests/managers/ordering_tests.py b/SoftLayer/tests/managers/ordering_tests.py
index <HASH>..<HASH> 100644
--- a/SoftLayer/tests/managers/ordering_tests.py
+++ b/SoftLayer/tests/managers/ordering_tests.py
@@ -5,12 +5,12 @@
:license: MIT, see LICENSE for more details.
"""
from SoftLayer impo... | Fix pep8 naming for ordering manager
To be in sync with changes from pull request #<I> | softlayer_softlayer-python | train |
9337762e781da90cfc182f43a2ac80e61aac273f | diff --git a/stanza/utils/datasets/prepare_tokenizer_treebank.py b/stanza/utils/datasets/prepare_tokenizer_treebank.py
index <HASH>..<HASH> 100755
--- a/stanza/utils/datasets/prepare_tokenizer_treebank.py
+++ b/stanza/utils/datasets/prepare_tokenizer_treebank.py
@@ -829,9 +829,7 @@ def check_gum_ready(udbase_dir):
d... | Use the handparsed treebank as part of the en_combined models | stanfordnlp_stanza | train |
9cf43a6bbb908b133f01d10d414460c28bf2ee62 | diff --git a/Document/DocumentTrait.php b/Document/DocumentTrait.php
index <HASH>..<HASH> 100644
--- a/Document/DocumentTrait.php
+++ b/Document/DocumentTrait.php
@@ -47,14 +47,6 @@ trait DocumentTrait
public $ttl;
/**
- * When document is cloned id is set to null.
- */
- public function __clone(... | Do not reset document ID on clone | ongr-io_ElasticsearchBundle | train |
361ada5ab9b580cd980d4ef53f5735507bd6d3c4 | diff --git a/CHANGELOG.md b/CHANGELOG.md
index <HASH>..<HASH> 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,3 +1,6 @@
+## edge (planned for 1.3)
+* no need for explicit call to auto_html_prepare
+
## 1.2.1, released 2009-10-28
* more options for vimeo filter
diff --git a/lib/auto_html/auto_html_for.rb b/lib/au... | no need for explicit call to auto_html_prepare | dejan_auto_html | train |
5f7ae353a0ca9cadaf8fdc8803e1227ee6583d25 | diff --git a/CHANGELOG b/CHANGELOG
index <HASH>..<HASH> 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,4 +1,7 @@
0.22.2 (grover)
+ Facts are now cached in the state file, and when they change the configuration
+ is always recompiled. (#519)
+
Added 'ignoreimport' setting for use in commit hooks. This causes ... | Fixing #<I>. The facts are now cached in the state file and changes to them force a recompile.
git-svn-id: <URL> | puppetlabs_puppet | train |
44371938da9b934d1562b6fa39cbcb780e4b7a8f | diff --git a/indra/preassembler/__init__.py b/indra/preassembler/__init__.py
index <HASH>..<HASH> 100644
--- a/indra/preassembler/__init__.py
+++ b/indra/preassembler/__init__.py
@@ -390,10 +390,11 @@ class Preassembler(object):
for g in group_sizes:
total_comps += g ** 2
logger.debug("To... | Don't call np.max on empty list
This fixes tests in test_incremental_model that were failing. | sorgerlab_indra | train |
17266ff7c48c79b7f0ab06b42df9f504d655d880 | diff --git a/vb_suite/test_perf.py b/vb_suite/test_perf.py
index <HASH>..<HASH> 100755
--- a/vb_suite/test_perf.py
+++ b/vb_suite/test_perf.py
@@ -346,8 +346,7 @@ def print_report(df,h_head=None,h_msg="",h_baseline=None,b_msg=""):
stats_footer = "\n"
if args.stats :
- for l in df.index:
- ... | BLD: test_perf, print stats as table | pandas-dev_pandas | train |
a73c0967b42c67450d800693094c9fdba681f240 | diff --git a/pymatgen/command_line/enumlib_caller.py b/pymatgen/command_line/enumlib_caller.py
index <HASH>..<HASH> 100644
--- a/pymatgen/command_line/enumlib_caller.py
+++ b/pymatgen/command_line/enumlib_caller.py
@@ -223,7 +223,7 @@ class EnumlibAdaptor(object):
self.ordered_sites = []
if self.che... | Check len of ordered sites before popping. | materialsproject_pymatgen | train |
b87e6ba7c01c7de8262939ad46563ccfca08855d | diff --git a/lib/drone.js b/lib/drone.js
index <HASH>..<HASH> 100644
--- a/lib/drone.js
+++ b/lib/drone.js
@@ -103,7 +103,7 @@ Drone.prototype.connect = function (callback) {
connectedRun = true;
}
if (error) {
- if (callback) {
+ if (typeof callback === 'function') {
cal... | Protect all of the callbacks for when it is not provided. | voodootikigod_node-rolling-spider | train |
b049f141f35cec71fce3d2c7899ebac95b11d881 | diff --git a/src/java/arjdbc/jdbc/JdbcResult.java b/src/java/arjdbc/jdbc/JdbcResult.java
index <HASH>..<HASH> 100644
--- a/src/java/arjdbc/jdbc/JdbcResult.java
+++ b/src/java/arjdbc/jdbc/JdbcResult.java
@@ -24,7 +24,7 @@ public class JdbcResult extends RubyObject {
protected final RubyArray values;
protected ... | [postgres] Fixed issue where AR was trying to unescape already unescaped binary data | jruby_activerecord-jdbc-adapter | train |
dcf546275ba5a1497fb6988b934f8c5da6900080 | diff --git a/lib/jekyll/site.rb b/lib/jekyll/site.rb
index <HASH>..<HASH> 100644
--- a/lib/jekyll/site.rb
+++ b/lib/jekyll/site.rb
@@ -14,16 +14,19 @@ module Jekyll
# config - A Hash containing site configuration details.
def initialize(config)
self.config = config.clone
-
self.safe ... | Tweaked plugin directory handling, tests. | jekyll_jekyll | train |
d27758eb47dce5210859ea3c7ede27d34c49ad2c | diff --git a/src/Element/Group.php b/src/Element/Group.php
index <HASH>..<HASH> 100644
--- a/src/Element/Group.php
+++ b/src/Element/Group.php
@@ -2,29 +2,6 @@
namespace Jstewmc\Rtf\Element;
-/**
- * A group consists of text, control words, or control symbols enclosed in brackets
- * ("{" and "}"). The opening bra... | A little more cleanup (and fix linting issue) | jstewmc_rtf | train |
bb9749ebfd6122c570d6596b543c47d73790fc6e | diff --git a/src/Providers/OEmbed/WordPress.php b/src/Providers/OEmbed/WordPress.php
index <HASH>..<HASH> 100644
--- a/src/Providers/OEmbed/WordPress.php
+++ b/src/Providers/OEmbed/WordPress.php
@@ -22,7 +22,7 @@ class WordPress extends OEmbedImplementation
*/
public static function getPatterns()
{
- ... | fixed wordpress oembed provider | oscarotero_Embed | train |
ecb47751245e5e87f01700be206fef2c8c535746 | diff --git a/src/test/java/com/stripe/StripeTest.java b/src/test/java/com/stripe/StripeTest.java
index <HASH>..<HASH> 100644
--- a/src/test/java/com/stripe/StripeTest.java
+++ b/src/test/java/com/stripe/StripeTest.java
@@ -51,6 +51,7 @@ import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assert... | Added test that setting and saving dispute evidence works. | stripe_stripe-java | train |
9ed61bbb108647a0b45a150ebab37e64bcf17d4c | diff --git a/lib/fog/rackspace/service.rb b/lib/fog/rackspace/service.rb
index <HASH>..<HASH> 100644
--- a/lib/fog/rackspace/service.rb
+++ b/lib/fog/rackspace/service.rb
@@ -55,7 +55,11 @@ module Fog
private
def process_response(response)
- if response && response.body && response.body.is_a?(Str... | [rackspace] updating to only parse json if the body of the response has data | fog_fog | train |
35e5f091afb11b7573f6bb51e3a2dd52e0779752 | diff --git a/src/assets/js/index.js b/src/assets/js/index.js
index <HASH>..<HASH> 100644
--- a/src/assets/js/index.js
+++ b/src/assets/js/index.js
@@ -27,6 +27,8 @@ const createTooltips = () => {
});
};
+createTooltips();
+
const copyToClipboard = str => {
// Create a <textarea> element
const el = document.cr... | make tooltips work on initial load
currently they onyl work when the polyfill-library select input has it's value changed.
running `createTooltips()` on script execution fixes this | Financial-Times_polyfill-service | train |
4a634f667d5b0ea583ef45154b3aac2ffcff3551 | diff --git a/components/api/src/main/java/org/openengsb/core/api/xlink/model/ModelToViewsTupel.java b/components/api/src/main/java/org/openengsb/core/api/xlink/model/ModelToViewsTupel.java
index <HASH>..<HASH> 100644
--- a/components/api/src/main/java/org/openengsb/core/api/xlink/model/ModelToViewsTupel.java
+++ b/comp... | [OPENENGSB-<I>] added emtpy constructor to models for json serialization
(cherry picked from commit fdd0f<I>a5a<I>bea<I>d8bc<I>e3af7) | openengsb_openengsb | train |
dd0e3e2893a52cc3b11ef2f2f22ffe245386b853 | diff --git a/code/administrator/components/com_default/templates/helpers/toolbar.php b/code/administrator/components/com_default/templates/helpers/toolbar.php
index <HASH>..<HASH> 100644
--- a/code/administrator/components/com_default/templates/helpers/toolbar.php
+++ b/code/administrator/components/com_default/templat... | re #3: Render Joomla <I> style toolbars with <I>% same markup as Joomla | timble_kodekit | train |
d48c2ef957544008f6b0f874ae2e9ab2a0c95726 | diff --git a/core/packets.go b/core/packets.go
index <HASH>..<HASH> 100644
--- a/core/packets.go
+++ b/core/packets.go
@@ -95,6 +95,8 @@ func UnmarshalPacket(data []byte) (interface{}, error) {
packet = new(jpacket)
case typeCPacket:
packet = new(cpacket)
+ case typeSPacket:
+ packet = new(spacket)
}
err... | [issues/#<I>+#<I>] Add SPacket type | TheThingsNetwork_ttn | train |
5c0688482117cef3727b7fb1e0fe082ac71f6acd | diff --git a/lib/data_mapper.rb b/lib/data_mapper.rb
index <HASH>..<HASH> 100644
--- a/lib/data_mapper.rb
+++ b/lib/data_mapper.rb
@@ -160,7 +160,7 @@ module DataMapper
def self.repository(name = nil) # :yields: current_context
# TODO return context.last if last.name == name (arg)
current_repository = if n... | fixed bug where objects from relationships did not use identity-map, due to always creating a new repository when fetching objects | datamapper_dm-core | train |
e2b80c4cc4c952f63ccc6038f73899de9b7e2708 | diff --git a/classes/models/db.php b/classes/models/db.php
index <HASH>..<HASH> 100644
--- a/classes/models/db.php
+++ b/classes/models/db.php
@@ -539,8 +539,10 @@ class Db implements \Technote\Interfaces\Singleton, \Technote\Interfaces\Hook, \
$fields[ $k ] .= ' AS ' . $option[1];
}
}
- } else ... | DB:select の field 指定方法追加 column => as name | technote-space_wordpress-plugin-base | train |
744ba18b5d61ffe541f3ae28ac3405246dc1abde | diff --git a/Todo.rdoc b/Todo.rdoc
index <HASH>..<HASH> 100644
--- a/Todo.rdoc
+++ b/Todo.rdoc
@@ -7,6 +7,7 @@
== Minor
* Add arbitrary help blocks to sub-commands as well
+* Spec for changing out formatters (mock formatter)
* Add optional default command when none is present
* Fix multi-word command template cre... | Added spec helper #run to spec_helper.rb; using in runner_spec.rb | commander-rb_commander | train |
2e9fda6ead9e79c199dcc32b6b72b50cf88a049f | diff --git a/examples/callable_numerical_model.py b/examples/callable_numerical_model.py
index <HASH>..<HASH> 100644
--- a/examples/callable_numerical_model.py
+++ b/examples/callable_numerical_model.py
@@ -19,7 +19,7 @@ a, b = parameters('a, b')
mixed_model = CallableNumericalModel(
{y1: nonanalytical_func, y2... | Updated example to this new compacter notation.
Lead by example. | tBuLi_symfit | train |
8ca39408c7c0dbfa8dae6b57e76f00168639a423 | diff --git a/transfer/project.py b/transfer/project.py
index <HASH>..<HASH> 100644
--- a/transfer/project.py
+++ b/transfer/project.py
@@ -416,7 +416,7 @@ def store_config(config, suffix = None):
config_path = os.path.join(home, '.transfer')
# call(['mkdir', '-p', config_path])
- os.makedirs(config_pa... | changed exists_ok to exist_ok | matthew-sochor_transfer | train |
4d436ebc8ad55e1d003191722466773ecbe51843 | diff --git a/lib/mtrack/core.rb b/lib/mtrack/core.rb
index <HASH>..<HASH> 100644
--- a/lib/mtrack/core.rb
+++ b/lib/mtrack/core.rb
@@ -39,6 +39,7 @@ module MTrack
submodule.instance_eval do
if @__mtrack__.nil?
@__mtrack__ = State.new(state)
+ extend Core
else
@__m... | Fix MTrack::Core inclusion when including Module. | gdeoliveira_mtrack | train |
e42aa5ebfa16a8fe5f8f087057a30ea5c2e6baa2 | diff --git a/Renderer.js b/Renderer.js
index <HASH>..<HASH> 100644
--- a/Renderer.js
+++ b/Renderer.js
@@ -35,7 +35,7 @@ var State = {
backgroundColor : [0.1, 0.1, 0.1, 1],
sunPosition: [3, 0, 0],
prevSunPosition: [0, 0, 0],
- exposure: 1.5,
+ exposure: 1,
dirtySky: true,
frame: 0,
s... | Renderer returned exposure to 1 for now | pex-gl_pex-renderer | train |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
--- a/grammpy/Rule.py
+++ b/grammpy/Rule.py
@@ -11,7 +11,9 @@ from .Constants import EPSILON
class Rule:
- #TODO rules -> rule -> left/right -> rules
+ #TODO rules -> rule -> left/right -> fromSymbol/toSymbol -> rules
+ fromSymbol ... | Add fromSymbol and toSymbol to rule | PatrikValkovic_grammpy | train |
80040fc8b076a612cc3d052cd809eb2fb27972c7 | diff --git a/alot/addressbooks.py b/alot/addressbooks.py
index <HASH>..<HASH> 100644